"""
Created for storing version number.
The version number will be placed here based on the tag in Github using the tags_marker.py script.

Having "0.0.15" in final releases is NOT allowed.
"""
__version__="0.0.15"
